@@ -1,6 +1,8 @@
-# $Id: Size.pm,v 1.9 2006/04/07 16:01:35 comdog Exp $
+# $Id$
 package HTTP::Size;
 use strict;
+use warnings;
+no warnings;
 
 =head1 NAME
 
@@ -62,7 +64,7 @@ use LWP::UserAgent;
 use URI;
 use HTTP::Request;
 
-$VERSION = 0.94;
+$VERSION = '1.13_01';
 
 my $User_agent = LWP::UserAgent->new();
 
@@ -264,11 +266,12 @@ members of the project can shepherd this module appropriately.
 
 brian d foy, C<< <bdfoy@cpan.org> >>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2000-2006, brian d foy, All Rights Reserved.
+Copyright (c) 2000-2007 brian d foy.  All rights reserved.
 
-You may redistribute this under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
